@@ -203,7 +203,7 @@ needed info.")
   (set (make-local-variable 'next-line-add-newlines) nil)
   (goto-char 1)
   (emms-stream-display)
-  (toggle-read-only 1)
+  (read-only-mode 1)
   (run-hooks 'emms-stream-hook)
   (set-buffer-modified-p nil)
   (message "EMMS Stream Menu"))
